==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translation type="vanished">Keine Objekte selektiert.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>Keine Objekte selektiert.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 auf Layer &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 auf %3 Layern</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation>%1 Objekte auf Layer &apos;%2&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 Entities on %2 Layers</source>
        <translation>%1 Objekte auf %2 Layern</translation>
    </message>
    <message>
        <source>Entities</source>
        <translation type="vanished">Objekte</translation>
    </message>
    <message>
        <source>on</source>
        <translation type="vanished">auf</translation>
    </message>
    <message>
        <source> on </source>
        <translation type="obsolete"> auf </translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translation type="vanished">Layer &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Layer &quot;%1&quot;</source>
        <translation type="obsolete">Layer &quot;%1&quot;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translation type="vanished">%1 Layer</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translation>Selektierte Objekte:
%1.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translation type="vanished">Keine Objekte selektiert.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>Keine Objekte selektiert.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 auf Layer &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 auf %3 Layern</translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%n Entities on Layer &apos;%1&apos;</source>
        <translation>
            <numerusform>Ein Objekt auf Layer &apos;%1&apos;</numerusform>
            <numerusform>%n Objekte auf Layer &apos;%1&apos;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>%n Entities</source>
        <translation>
            <numerusform>Ein Objekt</numerusform>
            <numerusform>%n Objekte</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+0"/>
        <source>%n Layers</source>
        <translation>
            <numerusform>einem Layer</numerusform>
            <numerusform>%n Layer</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation type="vanished">%1 Objekte auf Layer &apos;%2&apos;</translation>
    </message>
    <message>
        <source>%1 Entities on %2 Layers</source>
        <translation type="vanished">%1 Objekte auf %2 Layern</translation>
    </message>
    <message>
        <source>Entities</source>
        <translation type="vanished">Objekte</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>on</source>
        <translation>auf</translation>
    </message>
    <message>
        <source> on </source>
        <translation type="obsolete"> auf </translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translation type="vanished">Layer &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Layer &quot;%1&quot;</source>
        <translation type="obsolete">Layer &quot;%1&quot;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translation type="vanished">%1 Layer</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translation>Selektierte Objekte:
%1.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
</context>
</TS>
